@@ -1,22 +1,22 @@
 package Email::Sender::Transport::SMTP;
 # ABSTRACT: send email over SMTP
-$Email::Sender::Transport::SMTP::VERSION = '1.300022'; # TRIAL
+$Email::Sender::Transport::SMTP::VERSION = '1.300023'; # TRIAL
 use Moo;
-use Try::Tiny;
 
 use Email::Sender::Failure::Multi;
 use Email::Sender::Success::Partial;
 use Email::Sender::Role::HasMessage ();
 use Email::Sender::Util;
-use MooX::Types::MooseLike::Base qw(Bool Int Str);
+use MooX::Types::MooseLike::Base qw(Bool Int Str HashRef);
+use Net::SMTP 3.03;
 
 use utf8 (); # See below. -- rjbs, 2015-05-14
 
 #pod =head1 DESCRIPTION
 #pod
 #pod This transport is used to send email over SMTP, either with or without secure
-#pod sockets (SSL/TLS).  It is one of the most complex transports available, capable of
-#pod partial success.
+#pod sockets (SSL/TLS).  It is one of the most complex transports available, capable
+#pod of partial success.
 #pod
 #pod For a potentially more efficient version of this transport, see
 #pod L<Email::Sender::Transport::SMTP::Persistent>.
@@ -29,9 +29,15 @@ use utf8 (); # See below. -- rjbs, 2015-05-14
 #pod
 #pod =item C<host>: the name of the host to connect to; defaults to C<localhost>
 #pod
-#pod =item C<ssl>: 'ssl' / 'starttls' / undef, if true, passed to L<Net::SMTPS> doSSL.
+#pod =item C<ssl>: if 'starttls', use STARTTLS; if 'ssl' (or 1), connect securely;
+#pod otherwise, no security
 #pod
-#pod =item C<port>: port to connect to; defaults to 25 for non-SSL, 465 for 'ssl' and 587 for 'starttls'
+#pod =item C<ssl_options>: passed to Net::SMTP constructor for 'ssl' connections or
+#pod to starttls for 'starttls' connections; should contain extra options for
+#pod IO::Socket::SSL
+#pod
+#pod =item C<port>: port to connect to; defaults to 25 for non-SSL, 465 for 'ssl',
+#pod 587 for 'starttls'
 #pod
 #pod =item C<timeout>: maximum time in secs to wait for server; default is 120
 #pod
@@ -43,14 +49,36 @@ sub BUILD {
     if $self->host =~ /:/;
 }
 
-has host => (is => 'ro', isa => Str,  default => sub { 'localhost' });
-has ssl  => (is => 'ro', isa => Str);
+has host => (is => 'ro', isa => Str, default => sub { 'localhost' });
+has ssl  => (is => 'ro', isa => Str, default => sub { 0 });
+
+has _security => (
+  is   => 'ro',
+  lazy => 1,
+  init_arg => undef,
+  default  => sub {
+    my $ssl = $_[0]->ssl;
+    return '' unless $ssl;
+    $ssl = lc $ssl;
+    return 'starttls' if 'starttls' eq $ssl;
+    return 'ssl' if $ssl eq 1 or $ssl eq 'ssl';
+
+    Carp::cluck(qq{true "ssl" argument to Email::Sender::Transport::SMTP should be 'ssl' or 'startls' or '1' but got '$ssl'});
+
+    return 1;
+  },
+);
+
+has ssl_options => (is => 'ro', isa => HashRef, default => sub {  {}  });
+
 has port => (
   is  => 'ro',
   isa => Int,
   lazy    => 1,
   default => sub {
-    return $_[0]->ssl && $_[0]->ssl eq 'starttls' ?  587 : $_[0]->ssl ? 465 : 25
+    return $_[0]->_security eq 'starttls' ? 587
+         : $_[0]->_security eq 'ssl'      ? 465
+         :                                   25
   },
 );
 
@@ -107,23 +135,6 @@ sub _smtp_client {
   my ($self) = @_;
 
   my $class = "Net::SMTP";
-  if ($self->ssl) {
-    for (qw(Net::SMTPS Net::SMTP::SSL)) {
-      no warnings 'exiting';
-      try {
-        eval "require $_";
-        $class = $_;
-        last
-      };
-    }
-    Carp::croak(__PACKAGE__.": $class does not support starttls;".
-      " install Net::SMTPS for that")
-      if $class eq 'Net::SMTP::SSL' && $self->ssl eq 'starttls';
-    Carp::croak(__PACKAGE__.": SSL/TLS requires Net::SMTPS")
-      if $class eq 'Net::SMTP';
-  } else {
-    require Net::SMTP;
-  }
 
   my $smtp = $class->new( $self->_net_smtp_args );
 
@@ -135,6 +146,11 @@ sub _smtp_client {
     );
   }
 
+  if ($self->_security eq 'starttls') {
+    $self->_throw("can't STARTTLS: " . $smtp->message)
+      unless $smtp->starttls(%{ $self->ssl_options });
+  }
+
   if ($self->sasl_username) {
     $self->_throw("sasl_username but no sasl_password")
       unless defined $self->sasl_password;
@@ -154,15 +170,16 @@ sub _smtp_client {
 sub _net_smtp_args {
   my ($self) = @_;
 
-  # compatible
-  my $ssl = $self->ssl;
-  $ssl = 'ssl' if $self->ssl and $self->ssl ne 'starttls';
   return (
     $self->host,
     Port    => $self->port,
     Timeout => $self->timeout,
     Debug   => $self->debug,
-    defined $ssl             ? (doSSL     => $ssl)             : (),
+
+    (($self->_security eq 'ssl')
+      ? (SSL => 1, %{ $self->ssl_options })
+      : ()),
+
     defined $self->helo      ? (Hello     => $self->helo)      : (),
     defined $self->localaddr ? (LocalAddr => $self->localaddr) : (),
     defined $self->localport ? (LocalPort => $self->localport) : (),
@@ -286,17 +303,6 @@ sub _message_complete { $_[1]->quit; }
 #pod may return L<Email::Sender::Success::Partial> objects.  Consult that module's
 #pod documentation.
 #pod
-#pod =head1 EXAMPLES
-#pod
-#pod =head2 send email with Gmail
-#pod
-#pod   my $smtp  = Email::Sender::Transport::SMTP->new({
-#pod     host => 'smtp.gmail.com',
-#pod     ssl  => 'starttls',
-#pod     sasl_username => 'myaccount@gmail.com',
-#pod     sasl_password => 'mypassword',
-#pod   });
-#pod
 #pod =cut
 
 with 'Email::Sender::Transport';
@@ -315,13 +321,13 @@ Email::Sender::Transport::SMTP - send email over SMTP
 
 =head1 VERSION
 
-version 1.300022
+version 1.300023
 
 =head1 DESCRIPTION
 
 This transport is used to send email over SMTP, either with or without secure
-sockets (SSL/TLS).  It is one of the most complex transports available, capable of
-partial success.
+sockets (SSL/TLS).  It is one of the most complex transports available, capable
+of partial success.
 
 For a potentially more efficient version of this transport, see
 L<Email::Sender::Transport::SMTP::Persistent>.
@@ -334,9 +340,15 @@ The following attributes may be passed to the constructor:
 
 =item C<host>: the name of the host to connect to; defaults to C<localhost>
 
-=item C<ssl>: 'ssl' / 'starttls' / undef, if true, passed to L<Net::SMTPS> doSSL.
+=item C<ssl>: if 'starttls', use STARTTLS; if 'ssl' (or 1), connect securely;
+otherwise, no security
 
-=item C<port>: port to connect to; defaults to 25 for non-SSL, 465 for 'ssl' and 587 for 'starttls'
+=item C<ssl_options>: passed to Net::SMTP constructor for 'ssl' connections or
+to starttls for 'starttls' connections; should contain extra options for
+IO::Socket::SSL
+
+=item C<port>: port to connect to; defaults to 25 for non-SSL, 465 for 'ssl',
+587 for 'starttls'
 
 =item C<timeout>: maximum time in secs to wait for server; default is 120
 
@@ -362,17 +374,6 @@ If C<allow_partial_success> was set when creating the transport, the transport
 may return L<Email::Sender::Success::Partial> objects.  Consult that module's
 documentation.
 
-=head1 EXAMPLES
-
-=head2 send email with Gmail
-
-  my $smtp  = Email::Sender::Transport::SMTP->new({
-    host => 'smtp.gmail.com',
-    ssl  => 'starttls',
-    sasl_username => 'myaccount@gmail.com',
-    sasl_password => 'mypassword',
-  });
-
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@cpan.org>
